#
# spec file for package combustion
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           combustion
Version:        1.0+git2
Release:        150400.1.1
Summary:        System for initial configuration of appliances
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/openSUSE/combustion
Source0:        %{name}-%{version}.tar.xz
Requires:       ignition-dracut-grub2
BuildArch:      noarch

%description
Combustion is a minimal module for dracut, which runs a user provided script on
the first boot of a transactional system.

You can use this to create additional files, install packages, set up devices
or even re-partition the hard disk. The configuration can be provided as a
shell script, loaded from an external storage media and is run during boot in a
new system snapshot. On success, the system will directly boot into that new
snapshot, so that no reboot is needed.

%prep
%autosetup -p1

%build

%install
%make_install

%post
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%license LICENSE
%doc README.md
%dir %{_prefix}/lib/dracut/
%dir %{_prefix}/lib/dracut/modules.d/
%{_prefix}/lib/dracut/modules.d/35combustion/

%changelog
* Thu Aug 18 2022 fvogt@suse.com
- Update to version 1.0+git2:
  * Let selinux-microos-relabel decide whether a relabel is necessary (bsc#1202437)
* Tue Aug  2 2022 fvogt@suse.com
- Update to version 1.0+git1:
  * Use /lib/dracut/hooks instead of the usr-merged location (bsc#1201957)
* Wed Jul  6 2022 fvogt@suse.com
- Switch to use the git repo with obs_scm
- Update to version 1.0+git0:
  * Add Makefile for make install support
  * Start sysroot-usr.mount as well
  * Replace invalid use of ln_r in module-setup.sh
* Thu Mar 24 2022 fvogt@suse.com
- Bump version to 0.3
- Use the Wiki page as URL (boo#1195383)
- Don't touch /sysroot/etc/ after creating a new snapshot, it ends up
  in the old snapshot's overlay
* Wed Mar 23 2022 fvogt@suse.com
- Disable ignition-mount.service's ExecStop instead of stopping the
  unit (boo#1197309)
* Mon Mar 21 2022 fvogt@suse.com
- Be more --quiet with systemctl
* Thu Mar  3 2022 fvogt@suse.com
- Support the dracut network-manager module
* Mon Jan 24 2022 fvogt@suse.com
- Remove /var/lib/YaST2/reconfig_system on successful runs
* Wed Nov 24 2021 mitko@tuionui.com
- Look for filesystems with uppercase labels as well
* Tue Jul 27 2021 fvogt@suse.com
- Drop explicit dependency on sysroot.mount. Instead, handle starting and
  stopping of the unit explicitly to avoid conflicts.
- Add workaround for gh#systemd/systemd#20329
* Mon Jun 21 2021 fvogt@suse.com
- Set the exit status explicitly
* Mon Jun  7 2021 fvogt@suse.com
- combustion: Relabel the old snapshot (if necessary) and explicitly
  trigger autorelabel for the new snapshot
* Fri Mar  5 2021 fvogt@suse.com
- Expand and clarify README
* Wed Jan 20 2021 fvogt@suse.com
- module-setup.sh: Install grep as well
* Thu Oct 22 2020 fvogt@suse.com
- Change license to GPL-2.0-or-later
* Tue Oct 13 2020 fvogt@suse.com
- Also stop ignition-mount.service if there's no config
* Tue Oct  6 2020 fvogt@suse.com
- Implement support for systems without transactional-update
- Require rmdir explicitly
* Mon Oct  5 2020 fvogt@suse.com
- Fail properly when the retval file doesn't exist
- Stop ignition-mount.service to avoid conflict (boo#1176746)
* Thu Sep 17 2020 fvogt@suse.com
- Overhaul configuration fetching:
  * Add udev rules to wait for either ignition, combustion or
    fw_cfg drives
  * Allow combustion.firstboot in addition to ignition.firstboot
  M combustion
  A combustion-prepare.service
  M combustion.service
  M module-setup.sh
- Bump version to 0.2
* Mon Sep 14 2020 iforster@suse.com
- Avoid concurrent run of Ignition and Combustion initialization
  scripts to a avoid a duplicate mount of the same device.
* Fri Sep  4 2020 fvogt@suse.com
- Add combustion-prepare.service to enable network if needed:
  M combustion
  A combustion-prepare.service
  M combustion.service
  M module-setup.sh
- Don't fail if no config drive found to not break ignition with
  fw_cfg
* Fri Jul 17 2020 fvogt@suse.com
- Adjust README after removal of combustion-generator
- Switch to GPL-2.0-only
* Thu Jul  9 2020 fvogt@suse.com
- Also force mounting of /tmp
- Fix getting the script's return value
* Wed Jul  1 2020 fvogt@suse.com
- Set the timeout for the config device explicitly, like ignition-dracut
* Fri Jun 19 2020 fvogt@suse.com
- Drop dependency on ignition
* Thu Jun 18 2020 fvogt@suse.com
- Initial commit
